@@ -19,6 +19,6 @@ get '/' => sub {
 #};
 
 slug '/ex/slug/:slug', 'element';
-list '/ex/list/dummy', 'dummy_list', { category => 'dummy' };
-latest_page '/ex/mypage', 'mypage', { upper => { category => 'upper' }, lower => { category => 'lower' }};
+list '/ex/list/dummy', 'dummy_list', 'dummy';
+latest_page '/ex/mypage', 'mypage', { upper => 'upper', lower =>  'lower' };
 true;
