@@ -29,6 +29,9 @@ sub reset_database
 slug '/ex/slug/:slug', 'element';
 list '/ex/list/dummy', 'dummy_list', 'dummy';
 latest_page '/ex/mypage', 'mypage', { upper => 'upper', lower => 'lower' };
+slug '/exref/slug/:slug', 'element', { category => 'dummy' };
+list '/exref/list/dummy', 'dummy_list', { category => 'dummy' };
+latest_page '/exref/mypage', 'mypage', { upper => { category => 'upper' }, lower => { category => 'lower' } };
 
 get '/:lang/get-last-by-order/:cat' => sub {
     my $art = Strehler::Element::Article->get_last_by_order(params->{'cat'}, params->{'lang'});
